from __future__ import annotations


from reamber.base import item_props
from reamber.base.Bpm import Bpm


@item_props()
class BMSBpm(Bpm):
    ...
